<?php
/*
Plugin Name: Woocommerce Easy Content Restriction
Plugin URI:
Description: Makes restricting content based on user purchase easy
Version: 1.2.7
Author: SFNdesign, Curtis McHale
Author URI: http://sfndesign.ca
License: GPLv2 or later
Text Domain: wecr
*/

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

require_once( 'admin/metabox.php' );
require_once( 'inc/content-filters.php' );
require_once( 'inc/license.php' );
require_once( 'inc/db-upgrades.php' );
require_once( 'inc/shortcodes.php' );

if ( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {
	// load our custom updater
	include( dirname( __FILE__ ) . '/inc/EDD_SL_Plugin_Updater.php' );
}

if ( class_exists( 'bbPress' ) ){
	require_once( dirname( __FILE__ ) .'/inc/bbpress-content-filters.php' );
}

// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
if ( ! defined( 'SFN_STORE_URL' ) ){
	define( 'SFN_STORE_URL', 'http://sfndesign.ca' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file
}

// the name of your product. This should match the download name in EDD exactly
define( 'WECR_PLUGIN_NAME', 'Easy Restricted Content for WooCommerce' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

define( 'WECR_DB_VERSION', '1.2.1' );

class WECR{

	function __construct(){

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue' ) );

		add_action( 'admin_notices', array( $this, 'check_required_plugins' ) );

		add_action( 'admin_init', array( $this, 'plugin_updater' ) );

		// Internationalization
		add_action( 'init', array( $this, 'textdomain' ) );

		$this->constants();

		// Register hooks that are fired when the plugin is activated, deactivated, and uninstalled, respectively.
		register_activation_hook( __FILE__, array( $this, 'activate' ) );
		register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );
		register_uninstall_hook( __FILE__, array( __CLASS__, 'uninstall' ) );

	} // construct

	/**
	 * Checks for plugin updates based on the license key being valid
	 *
	 * @since 1.0
	 * @author SFNdesign, Curtis McHale
	 *
	 * @uses get_option()                   Gets given option from the WP DB
	 * @class EDD_Sl_Plugin_Updater()       EDD Plugin updater class
	 */
	public function plugin_updater() {

		// retrieve our license key from the DB
		$license_key = get_option( 'sfn_license' );
		$license_key = isset( $license_key['wecr_license'] ) ? trim( $license_key['wecr_license'] ) : null;

		// setup the updater
		$edd_updater = new EDD_SL_Plugin_Updater( SFN_STORE_URL, __FILE__, array(
				'version'   => '1.2.7',                     // current version number
				'license'   => $license_key,                // license key (used get_option above to retrieve from DB)
				'item_name' => WECR_PLUGIN_NAME,            // name of this plugin
				'author'    => 'SFNdesign, Curtis McHale',  // author of this plugin
			)
		);

	} // plugin_updater

	/**
	 * Internationalization
	 *
	 * @since 0.0.1
	 * @author SFNdesign, Curtis McHale
	 * @access public
	 * @static
	 *
	 * @return void
	 */
	public static function textdomain() {
		// Set filter for plugin's languages directory
		$wecr_lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
		$wecr_lang_dir = apply_filters( 'wecr_languages_directory', $wecr_lang_dir );

		// Load the translations
		load_plugin_textdomain( 'wecr', false, $wecr_lang_dir );

	} // textdomain

	/**
	 * Registers and enqueues scripts and styles
	 *
	 * @uses    wp_enqueue_style
	 * @uses    wp_enqueue_script
	 *
	 * @since   1.0
	 * @author  SFNdesign, Curtis McHale
	 */
	public function admin_enqueue(){

		$screen = get_current_screen();

		if ( in_array( $screen->post_type, $this->allowed_post_types() ) && $screen->base === 'post' ){
			// styles plugin
			wp_enqueue_style( 'chosen_styles', plugins_url( '/woocommerce-easy-content-restriction/lib/chosen/chosen.min.css' ), '', '0.0.1', 'all' );

			// scripts plugin
			wp_enqueue_script( 'chosen', plugins_url( '/woocommerce-easy-content-restriction/lib/chosen/chosen.jquery.min.js' ), array( 'jquery' ), '0.0.1', true );
			wp_enqueue_script( 'wecr_admin_scripts', plugins_url( '/woocommerce-easy-content-restriction/js/easy-content-restrict-admin-scripts.min.js' ), array( 'jquery' ), '0.0.1', true );
		}

		if ( $screen->base === 'woocommerce_page_sfn-license' ){
			wp_enqueue_style( 'sfn_license_styles', plugins_url( '/woocommerce-easy-content-restriction/js/sfn-license.css' ), '', '0.0.1', 'all' );
			wp_enqueue_script( 'sfn_license_script', plugins_url( '/woocommerce-easy-content-restriction/js/sfn-license-script.min.js' ), array( 'jquery' ), '0.0.1', true );
			wp_localize_script( 'sfn_license_script', 'SFNLicense', array(
				'ajaxurl'           => admin_url( 'admin-ajax.php' ),
				'sfn_license_nonce' => wp_create_nonce( 'sfn_license_nonce' ),
			) );
		}

	} // admin_enqueue

	/**
	 * Returns an array of allowed post_types for the restricted content plugin
	 *
	 * @since 0.0.1
	 * @author SFNdesign, Curtis McHale
	 * @access private
	 *
	 * @return array        The array of post_types we should be running on
	 */
	public function allowed_post_types(){

		$allowed = array(
			'post', 'page', 'forum'
		);

		return apply_filters( 'wecr_allowed_post_types', $allowed );

	} // allowed_post_types

	/**
	 * Checks for WooCommerce and GF and kills our plugin if they aren't both active
	 *
	 * @uses    function_exists     Checks for the function given string
	 * @uses    deactivate_plugins  Deactivates plugins given string or array of plugins
	 *
	 * @action  admin_notices       Provides WordPress admin notices
	 *
	 * @since   1.0
	 * @author  SFNdesign, Curtis McHale
	 */
	public function check_required_plugins(){

		if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ){ ?>

			<div id="message" class="error">
				<p>Easy Content Restriction expects WooCommerce to be active. This plugin has been deactivated.</p>
			</div>

			<?php
			deactivate_plugins( '/woocommerce-easy-content-restriction/woocommerce-easy-content-restriction.php' );

		} // compmany team if

	} // check_required_plugins

	/**
	 * Gives us any constants we need in the plugin
	 *
	 * @since 1.2.5
	 */
	public function constants(){

		define( 'WECR_DIR', plugin_dir_path( __FILE__ ) );

	}

	/**
	 * Adds the caps for reading restricted content to the roles
	 *
	 * @since 0.0.1
	 * @author SFNdesign, Curtis McHale
	 * @access private
	 *
	 * @uses get_role()         Returns the role object
	 * @uses add_cap()          Adds specified cap to the role
	 */
	private function add_reading_caps(){

		$admin = get_role( 'administrator' );
		if ( null !== $admin ){
			$admin->add_cap( 'wecr_read_content' );
		}

		$editor = get_role( 'editor' );
		if ( null !== $editor ){
			$editor->add_cap( 'wecr_read_content' );
		}

		$manager = get_role( 'shop_manager' );
		if ( null !== $manager ){
			$manager->add_cap( 'wecr_read_content' );
		}

	} // add_reading_caps

	/**
	 * Removes the caps for reading restricted content to the roles
	 *
	 * @since 0.0.1
	 * @author SFNdesign, Curtis McHale
	 * @access private
	 *
	 * @uses get_role()         Returns the role object
	 * @uses add_cap()          Adds specified cap to the role
	 */
	private function remove_reading_caps(){

		$admin = get_role( 'administrator' );
		$admin->remove_cap( 'wecr_read_content' );

		$editor = get_role( 'editor' );
		$editor->remove_cap( 'wecr_read_content' );

		$manager = get_role( 'shop_manager' );
		$manager->remove_cap( 'wecr_read_content' );

	} // add_reading_caps

	/**
	 * Fired when plugin is activated
	 *
	 * @param   bool    $network_wide   TRUE if WPMU 'super admin' uses Network Activate option
	 *
	 * @uses $this->add_reading_caps()          Adds the reading caps to the proper roles
	 */
	public function activate( $network_wide ){

		$this->add_reading_caps();

		add_option( 'wecr_db_version', WECR_DB_VERSION, '', 'no' );

	} // activate

	/**
	 * Fired when plugin is deactivated
	 *
	 * @param   bool    $network_wide   TRUE if WPMU 'super admin' uses Network Activate option
	 *
	 * @uses $this->remove_reading_caps()       Removes the reading caps for the plugin
	 */
	public function deactivate( $network_wide ){

		$this->remove_reading_caps();

	} // deactivate

	/**
	 * Fired when plugin is uninstalled
	 *
	 * @param   bool    $network_wide   TRUE if WPMU 'super admin' uses Network Activate option
	 */
	public function uninstall( $network_wide ){

	} // uninstall

} // WECR

$GLOBALS['wecr'] = new WECR();
